import random
def main():
	x="yes"
	while x!="no":
		print("(')")
		y=input("What color do you think this apple is: Red, Yellow, or Green?")
		z=random.choice(["Red", "Yellow", "Green"])
		if(y==z):
			x=input("Good Guess, want to play again? (yes/no)")
		else:
			print("Sorry, it was "+z+ " better luck next time!")
			x=input("Would you like to play again? (yes/no)")



main()



from distutils.core import setup

setup(
	name='Apples_Game',
        version= '0.1.1',
        author='Mahnoor Imran',
        author_email='mimran2@gmu.edu',
        packages=['applesGame'],
        url='http://pypi.python.org',
        license='MIT',
        description='Guess the color of the Apple!',
        long_description=open('README.rst').read(),
	classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.2",
        "Programming Language :: Python :: 3.3",
        "License :: OSI Approved :: MIT License",
        "Development Status :: 3 - Alpha",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
    ],        
)

